@@ -41,16 +41,60 @@ class ExperimentalGeospatialAPI(GeospatialAPI):
     def __init__(self, *args, **kwargs):
         super(ExperimentalGeospatialAPI, self).__init__(*args, **kwargs)
 
+        # https://stackoverflow.com/questions/6034662/python-method-overriding-does-signature-matter
+        # skip these methods from parent
+        skip_methods = [
+            "create_feature_types",
+            "coordinate_reference_systems",
+            "stream_features",
+            "compute",
+        ]
         for attr_name in GeospatialAPI.__dict__:
+            if any([method in attr_name for method in skip_methods]):
+                continue
             attr = getattr(self, attr_name)
-            if (
-                "coordinate_reference_systems" not in attr_name
-                and "stream_features" not in attr_name
-                and isinstance(attr, types.MethodType)
-            ):
+            if isinstance(attr, types.MethodType):
                 wrapped = _with_cognite_domain(getattr(GeospatialAPI, attr_name))
                 setattr(ExperimentalGeospatialAPI, attr_name, wrapped)
 
+    @_with_cognite_domain
+    def create_feature_types(
+        self, feature_type: Union[FeatureType, Sequence[FeatureType]]
+    ) -> Union[FeatureType, FeatureTypeList]:
+        """`Creates feature types`
+        <https://docs.cognite.com/api/v1/#operation/createFeatureTypes>
+
+        Args:
+            feature_type (Union[FeatureType, Sequence[FeatureType]]): feature type definition or list of feature type definitions to create.
+
+        Returns:
+            Union[FeatureType, FeatureTypeList]: Created feature type definition(s)
+
+        Examples:
+
+            Create new type definitions:
+
+                >>> from cognite.client import CogniteClient
+                >>> from cognite.client.data_classes.geospatial import FeatureType
+                >>> c = CogniteClient()
+                >>> feature_types = [
+                ...     FeatureType(external_id="wells", properties={"location": {"type": "POINT", "srid": 4326}})
+                ...     FeatureType(
+                ...       external_id="cities",
+                ...       properties={"name": {"type": "STRING", "size": 10}},
+                ...       search_spec={"name_index": {"properties": ["name"]}}
+                ...       partitions=[{"from":"2000", "to":"2007"},{"from":"2007", "to":"2020"}],
+                ...     )
+                ... ]
+                >>> res = c.geospatial.create_feature_types(feature_types)
+        """
+        return self._create_multiple(
+            list_cls=FeatureTypeList,
+            resource_cls=FeatureType,
+            items=feature_type,
+            resource_path=f"{self._RESOURCE_PATH}/featuretypes",
+        )
+
     @_with_cognite_domain
     def stream_features(
         self,
@@ -410,3 +454,72 @@ class ExperimentalGeospatialAPI(GeospatialAPI):
             extra_body_fields=extra_body_fields,
             limit=chunk_size,
         )
+
+    def create_tasks(
+        self,
+        session_nonce: str,
+        task: Union[GeospatialTask, Sequence[GeospatialTask]],
+    ) -> Union[GeospatialTask, GeospatialTaskList]:
+        """`Create tasks`
+        <https://pr-1916.specs.preview.cogniteapp.com/v1.json.html#tag/Geospatial/operation/createTasks>
+
+        Args:
+            session_nonce: the session nonce to be used by the background worker.
+            task: the task specification.
+
+        Returns:
+            Union[GeospatialTask, Sequence[GeospatialTask]]: created tasks
+
+        Examples:
+
+            Get one task:
+
+                >>> from cognite.client import CogniteClient
+                >>> c = CogniteClient()
+                >>> tasks = [
+                ...     GeospatialTask(
+                ...         external_id="my_task",
+                ...         task_type="FEATURES_INGESTION"
+                ...         task_spec={
+                ...             "fileExternalId": "data.csv",
+                ...             "intoFeatureType": "my_feature_type",
+                ...             "propeties": ["externalId", "tag"],
+                ...             "recreateIndex": True
+                ...         }
+                ...     )
+                ... ]
+                >>> res = c.geospatial.create_tasks(tasks)
+        """
+        return self._create_multiple(
+            list_cls=GeospatialTaskList,
+            resource_cls=GeospatialTask,
+            items=task,
+            resource_path=f"{GeospatialAPI._RESOURCE_PATH}/tasks",
+            extra_body_fields={"sessionNonce": session_nonce},
+        )
+
+    def get_tasks(self, external_id: Union[str, List[str]]) -> Union[GeospatialTask, GeospatialTaskList]:
+        """`Retrieve tasks`
+        <https://pr-1916.specs.preview.cogniteapp.com/v1.json.html#tag/Geospatial/operation/getTasksByIds>
+
+        Args:
+            external_id: the task external id.
+
+        Returns:
+            Union[GeospatialTask, Sequence[GeospatialTask]]: the retrieved task(s)
+
+        Examples:
+
+            Retrieve one task:
+
+                >>> from cognite.client import CogniteClient
+                >>> c = CogniteClient()
+                >>> res = c.geospatial.get_tasks(external_id="my_task")
+        """
+        identifiers = IdentifierSequence.load(ids=None, external_ids=external_id)
+        return self._retrieve_multiple(
+            list_cls=GeospatialTaskList,
+            resource_cls=GeospatialTask,
+            identifiers=identifiers.as_singleton() if identifiers.is_singleton() else identifiers,
+            resource_path=f"{GeospatialAPI._RESOURCE_PATH}/tasks",
+        )
