@@ -110,6 +110,14 @@ class AlertChannelFilter(CogniteFilter):
         self._cognite_client = cast("CogniteClient", cognite_client)
 
 
+class AlertTriggeredPoint:
+    """Triggered point, will be deduplicated into one or more alerts"""
+
+    def __init__(self, triggered: int, timestamp: int):
+        self.timestamp = timestamp
+        self.triggered = triggered
+
+
 class Alert(CogniteResource):
     """Alert"""
 
@@ -126,7 +134,7 @@ class Alert(CogniteResource):
         metadata: Dict[str, str] = None,
         acknowledged: bool = None,
         closed: bool = None,
-        triggered_points: List[Dict[str, str]] = None,
+        triggered_points: Optional[List[AlertTriggeredPoint]] = None,
         cognite_client: "CogniteClient" = None,
     ):
         self.id = id
@@ -144,56 +152,6 @@ class Alert(CogniteResource):
         self._cognite_client = cast("CogniteClient", cognite_client)
 
 
-class DeduplicateAlert(CogniteResource):
-    """Alert"""
-
-    def __init__(
-        self,
-        id: int = None,
-        external_id: str = None,
-        timestamp: int = None,
-        channel_id: int = None,
-        channel_external_id: str = None,
-        source: str = None,
-        value: str = None,
-        level: str = None,
-        metadata: Dict[str, str] = None,
-        acknowledged: bool = None,
-        closed: bool = None,
-        triggered_points: List[Dict[str, str]] = None,
-        cognite_client: "CogniteClient" = None,
-        status: str = None,
-        start_time: int = None,
-        last_triggered_time: int = None,
-        created_time: int = None,
-        last_updated_time: int = None,
-    ):
-        self.id = id
-        self.external_id = external_id
-        self.timestamp = timestamp
-        self.channel_id = channel_id
-        self.channel_external_id = channel_external_id
-        self.source = source
-        self.value = value
-        self.level = level
-        self.metadata = metadata
-        self.acknowledged = acknowledged
-        self.closed = closed
-        self.triggered_points = triggered_points
-        self._cognite_client = cast("CogniteClient", cognite_client)
-        self.status = status
-        self.last_triggered_time = last_triggered_time
-        self.created_time = created_time
-        self.last_updated_time = last_updated_time
-        self.start_time = start_time
-
-
-class DeduplicateAlertList(CogniteResourceList):
-    _RESOURCE = DeduplicateAlert
-    _UPDATE = None
-    _ASSERT_CLASSES = False
-
-
 class AlertList(CogniteResourceList):
     _RESOURCE = Alert
     _UPDATE = None
